
TODO_26_75_13_27: Make it explicit what fields are indexed (with keyword `indexed` in config).

Currently, `MongoClientWrapper.create_index` uses every field listed in `known_arg_types` in `static_data`.
But nothing ensures that the list of fields in complete - if this is required, it has to be validated.

It is not clear:
*   whether creating index is required or it only affects performance
*   whether creating index requirement is different for `pymongo` vs `mongomock`

